"""Translator collection.

The `translator` module provides a collection of translators for converting between
various formats related to optimization problems and their solutions.

Translators are categorized into two main groups:

1. **Model Translators**: These handle conversions *to* and *from* the internal `Model`
   representation. They enable interoperability between external formats
   (e.g., QUBO, LP) and the standardized internal model format used within the system.

2. **Solution Translators**: These support conversion *from* external solution formats
   into the internal `Solution` representation. This enables solutions generated by
   different solvers or formats to be interpreted and processed consistently within
   the system. Note that these translators do not support conversion *from* the internal
   solution to external formats.

Each translator encapsulates the logic needed for bidirectional format conversion,
ensuring consistency and modularity when integrating with diverse optimization
frameworks and solvers.
"""

from ._core.translator import *  # type: ignore[reportMissingImports] # noqa: F403
